@@ -58,45 +58,45 @@
 #include <pyside2_qtcore_python.h>
 
 // Binded library includes
-#include <qhelpsearchquerywidget.h>
 #include <qhelpenginecore.h>
-#include <qhelpindexwidget.h>
-#include <qhelpsearchresultwidget.h>
 #include <qhelpsearchengine.h>
 #include <qhelpcontentwidget.h>
 #include <qhelpengine.h>
+#include <qhelpsearchquerywidget.h>
+#include <qhelpindexwidget.h>
+#include <qhelpsearchresultwidget.h>
 // Conversion Includes - Primitive Types
+#include <signalmanager.h>
 #include <QString>
 #include <QStringList>
-#include <signalmanager.h>
 #include <qabstractitemmodel.h>
 
 // Conversion Includes - Container Types
-#include <QMap>
-#include <QLinkedList>
-#include <QList>
-#include <QVector>
 #include <QMultiMap>
+#include <QVector>
 #include <QStack>
+#include <QLinkedList>
 #include <QQueue>
 #include <QSet>
 #include <QPair>
 #include <pysideqflags.h>
+#include <QMap>
+#include <QList>
 
 // Type indices
 #define SBK_QHELPSEARCHRESULT_IDX                                    11
 #define SBK_QHELPSEARCHQUERY_IDX                                     8
 #define SBK_QHELPSEARCHQUERY_FIELDNAME_IDX                           9
 #define SBK_QHELPCONTENTITEM_IDX                                     0
-#define SBK_QHELPSEARCHQUERYWIDGET_IDX                               10
-#define SBK_QHELPSEARCHRESULTWIDGET_IDX                              12
-#define SBK_QHELPINDEXWIDGET_IDX                                     6
-#define SBK_QHELPCONTENTWIDGET_IDX                                   2
+#define SBK_QHELPSEARCHENGINE_IDX                                    7
 #define SBK_QHELPENGINECORE_IDX                                      4
 #define SBK_QHELPENGINE_IDX                                          3
-#define SBK_QHELPCONTENTMODEL_IDX                                    1
 #define SBK_QHELPINDEXMODEL_IDX                                      5
-#define SBK_QHELPSEARCHENGINE_IDX                                    7
+#define SBK_QHELPCONTENTMODEL_IDX                                    1
+#define SBK_QHELPSEARCHRESULTWIDGET_IDX                              12
+#define SBK_QHELPSEARCHQUERYWIDGET_IDX                               10
+#define SBK_QHELPCONTENTWIDGET_IDX                                   2
+#define SBK_QHELPINDEXWIDGET_IDX                                     6
 #define SBK_QtHelp_IDX_COUNT                                         13
 
 // This variable stores all Python types exported by this module.
@@ -106,21 +106,21 @@ extern PyTypeObject** SbkPySide2_QtHelpTypes;
 extern SbkConverter** SbkPySide2_QtHelpTypeConverters;
 
 // Converter indices
-#define SBK_QTHELP_QLIST_QACTIONPTR_IDX                              0 // QList<QAction* >
-#define SBK_QTHELP_QLIST_QHELPSEARCHQUERY_IDX                        1 // QList<QHelpSearchQuery >
-#define SBK_QTHELP_QVECTOR_INT_IDX                                   2 // const QVector<int > &
-#define SBK_QTHELP_QMAP_QSTRING_QURL_IDX                             3 // const QMap<QString,QUrl > &
-#define SBK_QTHELP_QLIST_QWIDGETPTR_IDX                              4 // QList<QWidget* >
-#define SBK_QTHELP_QLIST_QOBJECTPTR_IDX                              5 // const QList<QObject* > &
-#define SBK_QTHELP_QLIST_QBYTEARRAY_IDX                              6 // QList<QByteArray >
-#define SBK_QTHELP_QLIST_QURL_IDX                                    7 // QList<QUrl >
-#define SBK_QTHELP_QLIST_QSTRINGLIST_IDX                             8 // QList<QStringList >
-#define SBK_QTHELP_QHASH_INT_QBYTEARRAY_IDX                          9 // const QHash<int,QByteArray > &
-#define SBK_QTHELP_QMAP_INT_QVARIANT_IDX                             10 // QMap<int,QVariant >
-#define SBK_QTHELP_QLIST_QPERSISTENTMODELINDEX_IDX                   11 // const QList<QPersistentModelIndex > &
-#define SBK_QTHELP_QPAIR_QSTRING_QSTRING_IDX                         12 // QPair<QString,QString >
-#define SBK_QTHELP_QLIST_QPAIR_QSTRING_QSTRING_IDX                   13 // QList<QPair< QString,QString > >
-#define SBK_QTHELP_QVECTOR_QHELPSEARCHRESULT_IDX                     14 // QVector<QHelpSearchResult >
+#define SBK_QTHELP_QLIST_QOBJECTPTR_IDX                              0 // const QList<QObject* > &
+#define SBK_QTHELP_QLIST_QBYTEARRAY_IDX                              1 // QList<QByteArray >
+#define SBK_QTHELP_QPAIR_QSTRING_QSTRING_IDX                         2 // QPair<QString,QString >
+#define SBK_QTHELP_QLIST_QPAIR_QSTRING_QSTRING_IDX                   3 // QList<QPair< QString,QString > >
+#define SBK_QTHELP_QLIST_QHELPSEARCHQUERY_IDX                        4 // QList<QHelpSearchQuery >
+#define SBK_QTHELP_QVECTOR_QHELPSEARCHRESULT_IDX                     5 // QVector<QHelpSearchResult >
+#define SBK_QTHELP_QLIST_QURL_IDX                                    6 // QList<QUrl >
+#define SBK_QTHELP_QLIST_QSTRINGLIST_IDX                             7 // QList<QStringList >
+#define SBK_QTHELP_QMAP_QSTRING_QURL_IDX                             8 // QMap<QString,QUrl >
+#define SBK_QTHELP_QVECTOR_INT_IDX                                   9 // const QVector<int > &
+#define SBK_QTHELP_QHASH_INT_QBYTEARRAY_IDX                          10 // const QHash<int,QByteArray > &
+#define SBK_QTHELP_QMAP_INT_QVARIANT_IDX                             11 // QMap<int,QVariant >
+#define SBK_QTHELP_QLIST_QPERSISTENTMODELINDEX_IDX                   12 // const QList<QPersistentModelIndex > &
+#define SBK_QTHELP_QLIST_QACTIONPTR_IDX                              13 // QList<QAction* >
+#define SBK_QTHELP_QLIST_QWIDGETPTR_IDX                              14 // QList<QWidget* >
 #define SBK_QTHELP_QLIST_QVARIANT_IDX                                15 // QList<QVariant >
 #define SBK_QTHELP_QLIST_QSTRING_IDX                                 16 // QList<QString >
 #define SBK_QTHELP_QMAP_QSTRING_QVARIANT_IDX                         17 // QMap<QString,QVariant >
@@ -136,15 +136,15 @@ template<> inline PyTypeObject* SbkType< ::QHelpSearchResult >() { return reinte
 template<> inline PyTypeObject* SbkType< ::QHelpSearchQuery::FieldName >() { return SbkPySide2_QtHelpTypes[SBK_QHELPSEARCHQUERY_FIELDNAME_IDX]; }
 template<> inline PyTypeObject* SbkType< ::QHelpSearchQuery >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtHelpTypes[SBK_QHELPSEARCHQUERY_IDX]); }
 template<> inline PyTypeObject* SbkType< ::QHelpContentItem >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtHelpTypes[SBK_QHELPCONTENTITEM_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QHelpSearchQueryWidget >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtHelpTypes[SBK_QHELPSEARCHQUERYWIDGET_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QHelpSearchResultWidget >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtHelpTypes[SBK_QHELPSEARCHRESULTWIDGET_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QHelpIndexWidget >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtHelpTypes[SBK_QHELPINDEXWIDGET_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QHelpContentWidget >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtHelpTypes[SBK_QHELPCONTENTWIDGET_IDX]); }
+template<> inline PyTypeObject* SbkType< ::QHelpSearchEngine >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtHelpTypes[SBK_QHELPSEARCHENGINE_IDX]); }
 template<> inline PyTypeObject* SbkType< ::QHelpEngineCore >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtHelpTypes[SBK_QHELPENGINECORE_IDX]); }
 template<> inline PyTypeObject* SbkType< ::QHelpEngine >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtHelpTypes[SBK_QHELPENGINE_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QHelpContentModel >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtHelpTypes[SBK_QHELPCONTENTMODEL_IDX]); }
 template<> inline PyTypeObject* SbkType< ::QHelpIndexModel >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtHelpTypes[SBK_QHELPINDEXMODEL_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QHelpSearchEngine >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtHelpTypes[SBK_QHELPSEARCHENGINE_IDX]); }
+template<> inline PyTypeObject* SbkType< ::QHelpContentModel >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtHelpTypes[SBK_QHELPCONTENTMODEL_IDX]); }
+template<> inline PyTypeObject* SbkType< ::QHelpSearchResultWidget >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtHelpTypes[SBK_QHELPSEARCHRESULTWIDGET_IDX]); }
+template<> inline PyTypeObject* SbkType< ::QHelpSearchQueryWidget >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtHelpTypes[SBK_QHELPSEARCHQUERYWIDGET_IDX]); }
+template<> inline PyTypeObject* SbkType< ::QHelpContentWidget >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtHelpTypes[SBK_QHELPCONTENTWIDGET_IDX]); }
+template<> inline PyTypeObject* SbkType< ::QHelpIndexWidget >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtHelpTypes[SBK_QHELPINDEXWIDGET_IDX]); }
 
 } // namespace Shiboken
 
